summaryrefslogtreecommitdiff
path: root/compiler/specialise
diff options
context:
space:
mode:
authorSimon Peyton Jones <simonpj@microsoft.com>2017-02-27 09:09:26 -0500
committerDavid Feuer <David.Feuer@gmail.com>2017-02-27 09:11:26 -0500
commit0f7a369f78b7ef05d958d331bb02ad2d361abee0 (patch)
tree26520c8a8338a68ad702ff67e182d959527ba4ca /compiler/specialise
parentc0af206f26b97d8d4f1c5722825577b27087c0a9 (diff)
downloadhaskell-0f7a369f78b7ef05d958d331bb02ad2d361abee0.tar.gz
Stop uniques ending up in SPEC rule names
Reviewers: austin, bgamari Subscribers: thomie Differential Revision: https://phabricator.haskell.org/D3191
Diffstat (limited to 'compiler/specialise')
-rw-r--r--compiler/specialise/Specialise.hs9
1 files changed, 5 insertions, 4 deletions
diff --git a/compiler/specialise/Specialise.hs b/compiler/specialise/Specialise.hs
index 0090417669..9e189df781 100644
--- a/compiler/specialise/Specialise.hs
+++ b/compiler/specialise/Specialise.hs
@@ -1293,10 +1293,11 @@ specCalls mb_mod env rules_for_me calls_for_me fn rhs
Just this_mod -- Specialising imoprted fn
-> text "SPEC/" <> ppr this_mod
- rule_name = mkFastString $ showSDocForUser dflags neverQualify $
- herald <+> ppr fn <+> hsep (map ppr_call_key_ty call_ts)
- -- This name ends up in interface files, so use showSDocForUser,
- -- otherwise uniques end up there, making builds
+ rule_name = mkFastString $ showSDoc dflags $
+ herald <+> ftext (occNameFS (getOccName fn))
+ <+> hsep (map ppr_call_key_ty call_ts)
+ -- This name ends up in interface files, so use occNameString.
+ -- Otherwise uniques end up there, making builds
-- less deterministic (See #4012 comment:61 ff)
rule_wout_eta = mkRule